@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use POE qw(Component::IRC Component::IRC::Plugin::Connector);
 
-our $VERSION = '0.04';
+our $VERSION = '0.06';
 
 sub init {
   my $package = shift;
@@ -15,7 +15,7 @@ sub init {
   my $heap = $config->{IRC};
   POE::Session->create(
      package_states => [
-        __PACKAGE__, [qw(_start _start_up irc_registered irc_001 sbox_smoke sbox_stop)],
+        __PACKAGE__, [qw(_start _start_up irc_registered irc_001 sbox_smoke sbox_stop sbox_perl_info)],
      ],
      heap => $heap,
   );
@@ -63,6 +63,13 @@ sub _get_channels {
   return @channels;
 }
 
+sub sbox_perl_info {
+  my ($kernel,$heap,$vers,$arch) = @_[KERNEL,HEAP,ARG0,ARG1];
+  my $message = "Smoking v$vers built for $arch";
+  $heap->{_irc}->yield( 'privmsg', $_, $message ) for _get_channels( $heap->{channels} );
+  return;
+}
+
 sub sbox_smoke {
   my ($kernel,$heap,$data) = @_[KERNEL,HEAP,ARG0];
   my $dist = $data->{job}->module();
